@@ -22,14 +22,21 @@ List cpp_lda(arma::sp_mat &mt, int k, int max_iter, double alpha, double beta,
     if (verbose)
         lda.verbose = verbose;
     if (lda.init_est() == 0) {
-        if (arma::size(seeds) == arma::size(lda.nw) && arma::accu(seeds) > 0) {
-            // set pseudo count as weak supervision
-            arma::umat s = arma::conv_to<arma::umat>::from(arma::mat(seeds));
-            lda.nw = lda.nw + s;
+        bool seeded = arma::accu(seeds) > 0;
+        arma::umat s;
+        if (seeded) {
+            if (arma::size(seeds) != arma::size(lda.nw))
+                std::invalid_argument("Invalid seed matrix");
+            s = arma::conv_to<arma::umat>::from(arma::mat(seeds));
+            lda.nw = lda.nw + s; // set pseudo count
             //lda.nwsum = lda.nwsum + arma::sum(s, 0);
         }
         lda.estimate();
+        if (seeded)
+            lda.nwsum = lda.nwsum + arma::sum(s, 0);
     }
+    lda.compute_theta();
+    lda.compute_phi();
 
     return List::create(Rcpp::Named("k") = lda.K,
                         Rcpp::Named("iter") = lda.liter,
