@@ -1,4 +1,4 @@
-context("test textmodel_seededlda")
+context("textmodel_seededlda")
 
 require(quanteda)
 data(data_corpus_moviereviews, package = "quanteda.textmodels")
@@ -30,6 +30,18 @@ test_that("LDA is working", {
        topics(lda),
        c("topic1", "topic2", "topic3", "topic4", "topic5")
     )
+    expect_equal(
+        levels(topics(lda)),
+        c("topic1", "topic2", "topic3", "topic4", "topic5")
+    )
+    expect_equal(
+        rowSums(lda$phi),
+        c("topic1" = 1, "topic2" = 1, "topic3" = 1, "topic4" = 1, "topic5" = 1)
+    )
+    expect_equal(
+        rowSums(lda$theta),
+        structure(rep(1, ndoc(dfmt)), names = docnames(dfmt))
+    )
     expect_equal(
         ncol(terms(textmodel_lda(dfmt, k = 1))), 1
     )
@@ -44,8 +56,25 @@ test_that("LDA is working", {
         print(lda),
         "Topics: 5; 500 documents; 22605 features."
     )
+
 })
 
+
+test_that("LDA works with empty documents", {
+
+    dfmt_empty <- dfmt
+    dfmt_empty[c(100, 200, 300),] <- 0
+    dfmt_empty <- as.dfm(dfmt_empty)
+
+    set.seed(1234)
+    lda_empty <- textmodel_lda(dfmt_empty, k = 5)
+    expect_true(
+        all(is.na(topics(lda_empty)[c(100, 200, 300)]))
+    )
+
+})
+
+
 test_that("seeded LDA is working", {
 
     dict <- dictionary(list(romance = c("love*", "couple*"),
@@ -73,6 +102,18 @@ test_that("seeded LDA is working", {
         topics(lda),
         c("romance", "sifi", "other")
     )
+    expect_equal(
+        levels(topics(lda)),
+        c("romance", "sifi", "other")
+    )
+    expect_equal(
+        rowSums(lda$phi),
+        c("romance" = 1, "sifi" = 1, "other" = 1)
+    )
+    expect_equal(
+        rowSums(lda$theta),
+        structure(rep(1, ndoc(dfmt)), names = docnames(dfmt))
+    )
     expect_equal(
         ncol(terms(textmodel_seededlda(dfmt, dict, residual = FALSE))), 2
     )
